<?php
// Copyright (C) <2015>  <it-novum GmbH>
//
// This file is dual licensed
//
// 1.
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, version 3 of the License.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// 2.
//  If you purchased an openITCOCKPIT Enterprise Edition you can use this file
//  under the terms of the openITCOCKPIT Enterprise Edition license agreement.
//  License agreement and license key will be shipped with the order
//  confirmation.

namespace LinuxBasicMonitoringModule\Lib\InitialDatabase;

use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package LinuxBasicMonitoringModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {
    public function __construct() {
        $TemplateImporter = new \App\itnovum\openITCOCKPIT\ImportTemplates\TemplateImport(
            \Cake\ORM\TableRegistry::getTableLocator()->get('Commands'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Macros'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Servicetemplates'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Hosttemplates'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Servicetemplategroups')
        );
        $TemplateImporter->import($this->getData());
    }

    public function getData() {
        return [
            'Commands'              => $this->getCommandsData(),
            'Macros'                => $this->getMacrosData(),
            'Hosttemplates'         => $this->getHosttemplatesData(),
            'Servicetemplates'      => $this->getServicetemplatesData(),
            'Servicetemplategroups' => $this->getServicetemplategroupsData()
        ];
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            0 =>
                [
                    'name'             => 'check_nrpe',
                    'command_line'     => '$USER1$/check_nrpe -H $HOSTADDRESS$ -c $ARG1$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'description'      => 'Check by NRPE without command args',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'command',
                                ],
                        ],
                ],
            1 =>
                [
                    'name'             => 'check_nrpe_args',
                    'command_line'     => '$USER1$/check_nrpe -H $HOSTADDRESS$ -c $ARG1$ $ARG2$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '64118aca-6528-4d9f-9db8-f24ccd6e5971',
                    'description'      => 'Check by NRPE with command args',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Command',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Arguments',
                                ],
                        ],
                ],
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getMacrosData() {
        $data = [
            /*
            [
                'name'        => '$USER1$',
                'value'       => 'foo',
                'description' => 'bar',
                'password'    => '0',
                'created'     => '2020-05-13 14:11:30',
                'modified'    => '2020-05-13 14:11:30'
            ],
            [
                'name'        => '$USER2$',
                'value'       => 'bar',
                'description' => 'baz',
                'password'    => '0',
                'created'     => '2020-05-13 14:11:41',
                'modified'    => '2020-05-13 14:11:41'
            ]
            */
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getHosttemplatesData() {
        $data = [
            /*
            [
                'id'                                => '2',
                'uuid'                              => 'd2f712ef-fc7e-4004-9bdc-8c819f00fff',
                'name'                              => 'My Hosttemplate',
                'description'                       => '',
                'hosttemplatetype_id'               => '1',
                'command_id'                        => 'bc922eb4-84ad-44cc-9dff-43a464097753',
                ...
            ],
            [
                'id'                                => '3',
                'uuid'                              => '82e7245a-f1be-41cd-b074-ff88681f7fff',
                'name'                              => 'Another Hosttemplate',
                'description'                       => '',
                'hosttemplatetype_id'               => '1',
                'command_id'                        => 'bc922eb4-84ad-44cc-9dff-43a464097753',
                ...
            ]
            */
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0 =>
                [
                    'uuid'                                      => '028c198b-73d6-409d-8b6b-8f73e31d262c',
                    'template_name'                             => 'LINUX_NRPE_LOAD',
                    'name'                                      => 'LINUX_NRPE_LOAD',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Linux NRPE load',
                    'command_id'                                => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '90',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '0',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-06-22 11:27:14',
                    'modified'                                  => '2017-06-27 10:07:15',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'check_load',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            1 =>
                [
                    'uuid'                                      => 'bd14d026-eed3-47e6-8b30-daea6536ac98',
                    'template_name'                             => 'LINUX_NRPE_DISK',
                    'name'                                      => 'LINUX_NRPE_DISK',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Linux NRPE disk',
                    'command_id'                                => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '90',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '0',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-06-22 11:44:54',
                    'modified'                                  => '2017-06-27 10:07:02',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'check_disk',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            2 =>
                [
                    'uuid'                                      => 'f9a3c5ec-13d2-4f3f-943e-cb89461196d4',
                    'template_name'                             => 'LINUX_NRPE_ZOMBIE',
                    'name'                                      => 'LINUX_NRPE_ZOMBIE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Linux NRPE check zombie process',
                    'command_id'                                => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '90',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '0',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-06-22 12:05:54',
                    'modified'                                  => '2017-06-27 10:07:45',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'check_zombie_procs',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            3 =>
                [
                    'uuid'                                      => '558d7d38-1ad5-4232-81ff-0c9a638ec0e8',
                    'template_name'                             => 'LINUX_NRPE_MEMORY',
                    'name'                                      => 'LINUX_NRPE_MEMORY',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Linux NRPE check memory',
                    'command_id'                                => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '90',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '0',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-06-22 12:06:38',
                    'modified'                                  => '2017-06-27 10:07:28',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'check_memory',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            4 =>
                [
                    'uuid'                                      => 'fa282cbd-2a40-4b5a-b8f5-be80d2418320',
                    'template_name'                             => 'LINUX_NRPE_PROC',
                    'name'                                      => 'LINUX_NRPE_PROC',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Linux NRPE check process with Arguments',
                    'command_id'                                => '64118aca-6528-4d9f-9db8-f24ccd6e5971',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '90',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '0',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-03 12:44:27',
                    'modified'                                  => '2017-07-03 12:45:20',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'check_procs',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '-a \'-w 20 -c 150\'',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
        ];
        return $data;
    }

    public function getServicetemplategroupsData() {
        $data = [
            0 =>
                [
                    'uuid'             => '6fab8479-aeea-4acd-bd9b-28da0ffc7804',
                    'description'      => 'Linux Monitoring with NRPE Client',
                    'servicetemplates' =>
                        [
                            0 =>
                                [
                                    'id'   => 'bd14d026-eed3-47e6-8b30-daea6536ac98',
                                    'uuid' => 'bd14d026-eed3-47e6-8b30-daea6536ac98',
                                ],
                            1 =>
                                [
                                    'id'   => '028c198b-73d6-409d-8b6b-8f73e31d262c',
                                    'uuid' => '028c198b-73d6-409d-8b6b-8f73e31d262c',
                                ],
                            2 =>
                                [
                                    'id'   => '558d7d38-1ad5-4232-81ff-0c9a638ec0e8',
                                    'uuid' => '558d7d38-1ad5-4232-81ff-0c9a638ec0e8',
                                ],
                            3 =>
                                [
                                    'id'   => 'f9a3c5ec-13d2-4f3f-943e-cb89461196d4',
                                    'uuid' => 'f9a3c5ec-13d2-4f3f-943e-cb89461196d4',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'Linux Basic Monitoring NRPE',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ],
                ],
        ];
        return $data;
    }
}
